from pathlib import Path
from tkinter import *
from .Coleccion_Cubos import Coleccion, resource_path
import ast


def Seleccion(name, estados):
    def mostrar2(posicion):
        if estados[posicion]:
            estados[posicion] = 0
            cubos[posicion].config(bg='white', bd=0)
        else:
            estados[posicion] = 1
            cubos[posicion].config(bg='green', bd=5)

    def coleccion():
        with open(resource_path('codex/res/usuarios.txt'), 'r+') as file:
            lines = [ast.literal_eval(line) for line in file]

            for line in lines:
                if name in line:
                    line['Estado'] = estados

            file.seek(0)
            file.truncate()
            file.writelines([str(line) + '\n' for line in lines])

        root.destroy()
        Coleccion(carpeta, estados, name)
        

    root = Tk()
    root.geometry('560x550+10+10')
    root.iconbitmap(resource_path('codex/res/icono.ico'))
    if name == 'rubik':
        Label(root, text=f'BIENVENIDO ADMIN', font=('bauhaus 93', 40, 'italic'), fg='red').pack(expand=True, padx=10)
    else:
        Label(root, text=f'BIENVENIDO {name.upper()}', font=('bauhaus 93', 40, 'italic'), fg='red').pack(expand=True, padx=10)
    fr2 = Frame(root)
    fr2.pack(fill='x')
    Label(fr2, text=f'Que cubo deseas: ', font=('impact', 20), fg='black').pack(side=LEFT, pady=5)

    carpeta = Path(resource_path('codex/res/cubos'))
    cantidad_archivos = len(list(carpeta.glob('*')))

    #file.name  Nombre con Extension
    #file.stem  Nombre
    #file.suffix Extension

    frame = Frame(root)
    frame.pack()
    
    imagenes_cubos = [PhotoImage(file=f'{carpeta}/{file.name}') for file in carpeta.iterdir()]
    cubos = [Button(frame, image=imagenes_cubos[posicion], command=lambda pos=posicion: mostrar2(pos)) 
                                for posicion in range(cantidad_archivos)] # El problema al usar lambda dentro de un bucle es que solo captura el ultimo valor de la variable

    row = 0
    columna = 0
    for i,j in enumerate(carpeta.iterdir()):
        cubos[i].grid(row=row, column=columna, padx=15)
        Label(frame, text=j.stem).grid(row=row+1, column=columna)

        columna += 1
        if (i+5) % 4 == 0: #Para que hayan solo 4 imagenes en cada fila
            row += 2
            columna = 0
            
    Button(root, text='Aceptar', font=('bauhaus 93', 20), bg='blue', fg='white', command=coleccion).pack()

    for posicion in range(len(estados)):
        if estados[posicion]:
                cubos[posicion].config(bg='green', bd=5)
        else:
            cubos[posicion].config(bg='white', bd=0)
            

    root.mainloop()


from tkinter import messagebox
from tkinter import *
from pathlib import Path
import ast
from .Seleccion_Cubos import Seleccion, resource_path


def Login():
    def IN(e): #Usuario
        user.delete(0,END)

    def OUT(e):
        if not user.get():
            user.insert(0, 'Usuario')

    def ingreso():
        name = user.get() 
        passw = passw_entry.get()
        label_registrar.config(text='', fg='red', font=('stika small', 1))

        with open(resource_path('codex/res/usuarios.txt'), 'r') as file:
            numero_lineas = len(file.readlines())
            file.seek(0)
            lines = [ast.literal_eval(file.readline()) for i in range(numero_lineas)]

            for i in range(numero_lineas):
                if name in lines[i].keys():
                    passtwt = lines[i][name]
                    estados = lines[i]['Estado'] #Pieza clave para poner y quitar imagenes
                    
        try:
            if passw == passtwt:
                root.destroy()
                Seleccion(name, estados)
            else:
                messagebox.showerror('Error', 'Contraseña incorrecta!')
        except UnboundLocalError:
            messagebox.showerror('Error', 'Usuario o Contraseña incorrectos!')
    
    global registrando
    registrando = False
    def registrar():
        global registrando
        if registrando:
            registrando = False
            with open(resource_path('codex/res/usuarios.txt'), 'r+') as file:
                numero_lineas = len(file.readlines())
                file.seek(0) #Puntero regrese al inicio
                lines = [ast.literal_eval(file.readline()) for i in range(numero_lineas)]

                name = user.get().strip()
                passw = passw_entry.get().strip()
                exist = False

                if name=='' or passw.strip()=='':
                    messagebox.showerror('Error', 'COMPLETE LOS CAMPOS!')
                else: 
                    for i in range(numero_lineas):
                        if name in lines[i].keys():
                            exist = True
                            label_registrar.config(text='Ingrese usuario nuevo', fg='red', font=('stika small', 30))
                            messagebox.showerror('Error', 'USUARIO YA EXISTE!')
                            break
                    if not exist:
                        file.write(f"{{'{name}':'{passw}', 'Estado': {[0]*cantidad_archivos}}}\n")
                        label_registrar.config(text='Registrado', fg='green', font=('stika small', 30))
        else:
            registrando = True
            label_registrar.config(text='Registrando...', fg='red', font=('stika small', 30))

            user.delete(0,END)
            user.insert(0,'Usuario')

            passw_entry.delete(0,END)
            passw_entry.insert(0,'Password')
            passw_entry.config(show='')
                    

    root = Tk()
    root.title('Inicio de sesion')
    root.geometry('500x430+10+10')
    root.iconbitmap(resource_path('codex/res/icono.ico'))
    carpeta = Path(resource_path('codex/res/cubos'))
    cantidad_archivos = len(list(carpeta.glob('*')))

    Label(root, text='INICIE SESION', fg='dark blue', font=('showcard gothic', 40)).pack()

    user = Entry(root, text='Usuario', width= 30, font=('Arial', 40))
    user.insert(0, 'Usuario')
    user.bind('<FocusIn>', IN)
    user.bind('<FocusOut>', OUT)
    user.pack()

    Frame(root, bg='black', height=10).place(y=130, relwidth=1) #Fill no existe en Place, asi que se usa Relwidth
    Frame(root).pack(pady=20) #Separador

    def IN(e): #Password
        if registrando:
            passw_entry.delete(0,END)
            passw_entry.config(show='')
        else:
            passw_entry.delete(0,END)
            passw_entry.config(show='*')

    def OUT(e):
        if not passw_entry.get():
            passw_entry.insert(0, 'Password')
            passw_entry.config(show='')
        
    passw_entry = Entry(root, width=30, font=('Arial', 40))
    passw_entry.insert(0, 'Password')
    passw_entry.bind('<FocusIn>', IN) #Evento de click/tabulacion en el widget
    passw_entry.bind('<FocusOut>', OUT)   #Evento de que se salio del widget
    passw_entry.pack()

    Frame(root, bg='black', height=10).place(y=235, relwidth=1) 
    Frame(root).pack(pady=30) #Separador

    frame_label_registrar = Frame(root)
    frame_label_registrar.pack(fill='x')
    
    label_registrar = Label(root, font=('stika small', 1))
    label_registrar.place(y=245)

    ingresar = Button(root, border=3, text='Ingresar', command=ingreso, font=('Arial', 30))
    ingresar.pack()

    frame = Frame(root)
    frame.pack()
    Label(frame, text='No tiene cuenta?', font=('Arial', 20)).grid(row=0, column=0)
    registro = Button(frame, text='Registrarse', fg='blue', font=('Arial', 20), border=0, command=registrar)
    registro.grid(row=0, column=1)

    root.mainloop()

if __name__ == "__main__":
    Login()